# Manual - console-login-helper-messages

## Packages/subpackages

The following packages/subpackages provide the following functions:

| package                                | function |
| -------------------------------------- | --- |
| console-login-helper-messages          | base directory layout for this packge |
| console-login-helper-messages-issuegen | messages shown on serial console using issue (SSH keys, IP address for SSH) |
| console-login-helper-messages-motdgen  | messages shown using the motd paths after SSH in (system information) |
| console-login-helper-messages-profile  | messages shown using /etc/profile.d script, shown on login to bash terminal (failed systemd units) |

## Common operations

### Enabling messages

The following enables the `motd` and `issue` messages to show at boot:

```
systemctl enable \
  console-login-helper-messages-issuegen.service \
  console-login-helper-messages-motdgen.service
```

The `profile` messages are enabled by default by a symlink from `/etc/profile.d` at install.

### Appending messages

- To have a message appended to the same `motd` file generated by `console-login-helper-messages-motdgen.service`, the files to append can be dropped in `/etc/console-login-helper-messages/motd.d` or `/run/console-login-helper-messages/motd.d`
- Similarly, `issue` messages to append to the same `issue` file generated by `console-login-helper-messages-issuegen.service` can be dropped in `/etc/console-login-helper-messages/issue.d` or  or `/run/console-login-helper-messages/issue.d`

### Disabling messages

The following disables the `motd` and `issue`  messages from showing:

```
systemctl disable \
  console-login-helper-messages-issuegen.service \
  console-login-helper-messages-motdgen.service
```

The `profile` messages can be disabled only by uninstalling `console-login-helper-messages-profile`.

#### Silencing a generated message without disabling

Messages can be silenced, but not disabled from being generated.

- Currently, the `issue` generated by `console-login-helper-messages-issuegen.service` can be silenced only by uninstalling `console-login-helper-messages-issuegen`.
- Silence the `motd` generated by `console-login-helper-messages-motdgen.service` using a null symlink as follows:

    ```
    ln -s /dev/null /etc/motd.d/40_console-login-helper-messages.motd
    ```

### Recreating the symlinks

If a message is not showing, it could be because a symlink required to show the message was deleted. To recreate the symlinks, the following command can be used:

```
systemd-tmpfiles --create
```

### Regenerating the messages

To manually regenerate the `motd` or `issue`, the following commands can be used respectively:

```
systemctl restart console-login-helper-messages-motdgen.service
systemctl restart console-login-helper-messages-issuegen.service
```
